.. _recipe_asr.gw:

asr.gw
======


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.gw`-recipe.
This recipe is comprised of 3 steps, namely:

  - :py:func:`asr.gw.gs`
  - :py:func:`asr.gw.gw`
  - :py:func:`asr.gw.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.gw

or as a python module

.. code-block:: console

   $ python -m asr.gw

Detailed description
--------------------
DFT GW.

Steps
-----


asr.gw@gs
^^^^^^^^^
.. autofunction:: asr.gw.gs
   

asr.gw@gw
^^^^^^^^^
.. autofunction:: asr.gw.gw
   

asr.gw
^^^^^^
.. autofunction:: asr.gw.main
   